=========
Pynoramio
=========

About
=====
Pynoramio is a Python SDK for the `Panoramio data API <http://panoramio.com/api/data/api.html>`_.

Documentation
=============
Documentation is included in the docs directory.
The docs are also available on `<http://pynoramio.readthedocs.org/en/latest/>`_.

License
=======
Pynoramio is released with the MIT license. See ``LICENSE`` for the license text.

